@@ -23,6 +23,9 @@ if "_PLTR_COMPLETE" in os.environ:
 
 # Normal CLI execution
 from pltr.cli import app
+from pltr.utils.alias_resolver import inject_alias_resolution
 
 if __name__ == "__main__":
+    # Resolve aliases before running the app
+    inject_alias_resolution()
     app()
