@@ -11,12 +11,19 @@ from pltr.commands import (
     verify,
     dataset,
     folder,
+    project,
+    resource,
+    resource_role,
+    space,
     ontology,
+    orchestration,
     sql,
     admin,
     shell,
     completion,
     alias,
+    mediasets,
+    connectivity,
 )
 
 app = typer.Typer(
@@ -30,8 +37,23 @@ app.add_typer(configure.app, name="configure", help="Manage authentication profi
 app.add_typer(verify.app, name="verify", help="Verify authentication")
 app.add_typer(dataset.app, name="dataset", help="Manage datasets")
 app.add_typer(folder.app, name="folder", help="Manage folders")
+app.add_typer(project.app, name="project", help="Manage projects")
+app.add_typer(resource.app, name="resource", help="Manage resources")
+app.add_typer(
+    resource_role.app, name="resource-role", help="Manage resource permissions"
+)
+app.add_typer(space.app, name="space", help="Manage spaces")
 app.add_typer(ontology.app, name="ontology", help="Ontology operations")
+app.add_typer(
+    orchestration.app, name="orchestration", help="Manage builds, jobs, and schedules"
+)
 app.add_typer(sql.app, name="sql", help="Execute SQL queries")
+app.add_typer(
+    mediasets.app, name="media-sets", help="Manage media sets and media content"
+)
+app.add_typer(
+    connectivity.app, name="connectivity", help="Manage connections and data imports"
+)
 app.add_typer(
     admin.app,
     name="admin",
